// Package v16 provides migration for mongo repository
package v16

import (
	"context"
	"time"

	extras "gitlab.mashplace.com/mashplace/backend/extras/api"
	"gitlab.mashplace.com/mashplace/backend/extras/internal/model"
	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/mongo"
	"go.mongodb.org/mongo-driver/mongo/options"
)

func parseDate(s string) time.Time {
	t, _ := time.Parse(time.RFC3339, s)

	return t
}

// Up applies migration
func Up(ctx context.Context, db *mongo.Database, migrationID string) (int, error) {
	col := db.Collection("extras")

	// production data snapshot at 2022-07-21
	productionData := []bson.M{
		{
			"created": time.Now(),
			"updated": time.Now(),
			"code":    "landlord_listing_fee",
			"title":   "Platform Fee",
			"description": "Get your property live on Mashroom, Zoopla and Rightmove, get access to " +
				"Mashroom platform, chat to tenants, schedule viewing, draft and sign contracts online, and join " +
				"the community. We will also register your deposit, and arrange rent receipt from tenants. ",
			"reference_provider":   "",
			"page_url":             "",
			"main_icon_url":        "",
			"inventory_account":    "",
			"inventory_code":       "",
			"service_receivers":    nil,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       20,
			"inventory_offset":     0,
			"type":                 8,
			"role":                 4,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         false,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes":           bson.M{},
		},
		{
			"created": time.Now(),
			"updated": time.Now(),
			"code":    "landlord_referencing_check",
			"title":   "Referencing check",
			"description": "The checks cover Identity and Mobile phone verification, Credit file " +
				"assessment, Affordability assessment, CCJs, History of bankruptcy, Employment status, UK bank " +
				"account , Right to rent (preliminary check) and Previous Landlord/Agent referencing.",
			"reference_provider":   "",
			"page_url":             "",
			"main_icon_url":        "",
			"inventory_account":    "207",
			"inventory_code":       "1",
			"service_receivers":    nil,
			"price":                12.5,
			"tax_amount":           2.5,
			"tax_percentage":       20,
			"inventory_offset":     0,
			"type":                 14,
			"role":                 4,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         false,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes": bson.M{
				"document_type": "referencing_report",
			},
		},
		{
			"created": time.Now(),
			"updated": time.Now(),
			"code":    "landlord_epc_certificate",
			"title":   "Energy Performance Certificate",
			"description": "An Energy Performance Certificate is awarded to a property to give an " +
				"indication of its energy efficiency.",
			"reference_provider":   "",
			"page_url":             "https://mashroom.com/services/epc",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2021/12/tumb.png",
			"inventory_account":    "207",
			"inventory_code":       "8",
			"service_receivers":    nil,
			"price":                57.5,
			"tax_amount":           11.5,
			"tax_percentage":       20,
			"inventory_offset":     0,
			"type":                 7,
			"role":                 4,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         true,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes": bson.M{
				"vibrant":                  "EPC",
				"document_type":            "certificate",
				"document_validity_months": "60",
			},
		},
		{
			"created": time.Now(),
			"updated": time.Now(),
			"code":    "landlord_gas_certificate",
			"title":   "Gas Safety",
			"description": "Ensure that your tenant(s) lives in a safe environment with a Gas Safety " +
				"Certificate stating that any gas appliances are in good working order and don't pose any danger.",
			"reference_provider": "",
			"page_url":           "https://mashroom.com/services/gas-safety",
			"main_icon_url": "https://wordpress.mashroom.com/wp-content/uploads/2021/01/" +
				"Gas-safety-first-viewport-e1640083452771.png",
			"inventory_account":    "207",
			"inventory_code":       "3",
			"service_receivers":    nil,
			"price":                65.83,
			"tax_amount":           13.17,
			"tax_percentage":       20,
			"inventory_offset":     1,
			"type":                 7,
			"role":                 4,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         true,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes": bson.M{
				"vibrant":                  "Gas Safety Certificate",
				"document_type":            "certificate",
				"document_validity_months": "12",
			},
		},
		{
			"created":           time.Now(),
			"updated":           time.Now(),
			"service_receivers": nil,
			"code":              "landlord_inventory_unfurnished",
			"title":             "Inventory Unfurnished",
			"description": "The inventory is a detailed description of each room in the property as " +
				"well as the content and fixtures and fittings. It’s a way of documenting everything in the " +
				"property and its general condition, with tenants asked to agree and sign the inventory. " +
				"Find out more here.",
			"reference_provider":   "",
			"type":                 4,
			"role":                 4,
			"status":               extras.ServiceStatus_ACTIVE,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       20,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         false,
			"disabled":             true,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": true,
			"price_on_request":     false,
			"attributes": bson.M{
				"document_type": "inventory",
			},
		},
		{
			"created":           time.Now(),
			"updated":           time.Now(),
			"service_receivers": nil,
			"code":              "landlord_inventory_furnished",
			"title":             "Inventory Furnished",
			"description": "The inventory is a detailed description of each room in the property as well " +
				"as the content and fixtures and fittings. It’s a way of documenting everything in the property and " +
				"its general condition, with tenants asked to agree and sign the inventory. Find out more here.",
			"reference_provider":   "",
			"type":                 4,
			"role":                 4,
			"status":               extras.ServiceStatus_ACTIVE,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       20,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         false,
			"disabled":             true,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": true,
			"price_on_request":     false,
			"attributes": bson.M{
				"document_type": "inventory",
			},
		},
		{
			"created":           time.Now(),
			"updated":           time.Now(),
			"service_receivers": nil,
			"code":              "landlord_inventory_check_in_furnished",
			"title":             "Inventory and Check-In (Furnished)",
			"description": "This bundle of Inventory and Check-in simplifies your involvement in the " +
				"moving in process.",
			"reference_provider":   "",
			"type":                 11,
			"role":                 4,
			"status":               extras.ServiceStatus_ACTIVE,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       20,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         false,
			"disabled":             true,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": true,
			"price_on_request":     false,
			"attributes": bson.M{
				"vibrant":       "Furnished Inventory and check-in bson.M{bson.M{.BedroomsNo}}bed",
				"document_type": "check_in_report",
			},
		},
		{
			"created":           time.Now(),
			"updated":           time.Now(),
			"service_receivers": nil,
			"code":              "landlord_inventory_check_in_unfurnished",
			"title":             "Inventory and Check-In (Unfurnished)",
			"description": "This bundle of Inventory and Check-in simplifies your involvement in the " +
				"moving in process.",
			"reference_provider":   "",
			"type":                 11,
			"role":                 4,
			"status":               extras.ServiceStatus_ACTIVE,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       20,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         false,
			"disabled":             true,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": true,
			"price_on_request":     false,
			"attributes": bson.M{
				"vibrant":       "Unfurnished Inventory and check-in bson.M{bson.M{.BedroomsNo}}bed",
				"document_type": "check_in_report",
			},
		},
		{
			"created": time.Now(),
			"updated": time.Now(),
			"code":    "tenant_deposit",
			"title":   "Deposit",
			"description": "Tenants pay a tenancy deposit to give the landlord protection in case they " +
				"leave without paying the rent or cause damage to the property or its contents. Tenancy " +
				"deposit must be registered with an approved Tenancy Deposit administration scheme. " +
				"Find out more here.",
			"reference_provider":   "",
			"page_url":             "",
			"main_icon_url":        "",
			"inventory_account":    "",
			"inventory_code":       "",
			"service_receivers":    nil,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       0,
			"inventory_offset":     0,
			"type":                 9,
			"role":                 0,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             1,
			"primary":              false,
			"cart_product":         false,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": true,
			"price_on_request":     false,
			"attributes":           bson.M{},
		},
		{
			"created": time.Now(),
			"updated": time.Now(),
			"code":    "tenant_deposit_replacement",
			"title":   "Tenancy deposit replacement fee",
			"description": "Landlords enjoy a larger deposit protection (up to 12 weeks of rent). This " +
				"product allows tenants to move in quicker, replacing the traditional cash deposit. " +
				"Find out more here. ",
			"reference_provider":   "",
			"page_url":             "https://mashroom.com/services/deposit-replacement-tenant",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2021/02/cib3.png",
			"inventory_account":    "205",
			"inventory_code":       "14",
			"service_receivers":    nil,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       20,
			"inventory_offset":     0,
			"type":                 extras.ServiceType_DEPOSIT_INSURANCE,
			"role":                 extras.ServiceRole_TENANT_SERVICES,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             extras.TaxType_TAX_TYPE_VAT,
			"primary":              false,
			"cart_product":         false,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": true,
			"price_on_request":     false,
			"attributes":           bson.M{},
		},
		{
			"created": time.Now(),
			"updated": time.Now(),
			"code":    "landlord_check_out",
			"title":   "Check-Out",
			"description": "Have a professional check-out clerk collect keys and check if the property " +
				"is in the same condition as it was when the check-in was conducted.",
			"reference_provider":   "",
			"page_url":             "",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2021/02/cib1.png",
			"inventory_account":    "207",
			"inventory_code":       "2",
			"service_receivers":    nil,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       20,
			"inventory_offset":     0,
			"type":                 4,
			"role":                 0,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         true,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": true,
			"price_on_request":     false,
			"attributes": bson.M{
				"vibrant":       "Check-out bson.M{bson.M{.BedroomsNo}}bed",
				"document_type": "check_out_report",
			},
		},
		{
			"created": time.Now(),
			"updated": time.Now(),
			"code":    "landlord_photographs_floor_plans",
			"title":   "Professional photography",
			"description": "Show your property in its best light with the help of a professional " +
				"photographer and a floor plan.",
			"reference_provider":   "",
			"page_url":             "https://mashroom.com/services/professional-photography",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2021/01/Pro-Photo-1-viewport.png",
			"inventory_account":    "207",
			"inventory_code":       "7",
			"service_receivers":    nil,
			"price":                82.5,
			"tax_amount":           16.5,
			"tax_percentage":       20,
			"inventory_offset":     0,
			"type":                 12,
			"role":                 4,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         true,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes": bson.M{
				"vibrant":       "Professional photographs and Floor plans",
				"document_type": "photo",
			},
		},
		{
			"created": time.Now(),
			"updated": time.Now(),
			"code":    "landlord_home_emergency_insurance",
			"title":   "Home Emergency Insurance",
			"description": "Home Emergency Insurance provides you with 12 months of cover in case " +
				"of an emergency at your property.",
			"reference_provider":   "",
			"page_url":             "https://mashroom.com/services/home-emergency",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2021/01/EPC-3-icons-2-.png",
			"inventory_account":    "205.1",
			"inventory_code":       "6",
			"service_receivers":    nil,
			"price":                116.07,
			"tax_amount":           13.93,
			"tax_percentage":       12,
			"inventory_offset":     0,
			"type":                 13,
			"role":                 7,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             3,
			"primary":              false,
			"cart_product":         true,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes": bson.M{
				"vibrant":                  "Home Emergency Insurance",
				"document_type":            "home_emergency_insurance",
				"document_validity_months": "12",
			},
		},
		{
			"created":              time.Now(),
			"updated":              time.Now(),
			"code":                 "landlord_extra_listing",
			"title":                "Extra 30 days advertising",
			"description":          "Get 30 days of additional advertising for your property on Rightmove and Zoopla",
			"reference_provider":   "",
			"page_url":             "",
			"main_icon_url":        "",
			"inventory_account":    "",
			"inventory_code":       "",
			"service_receivers":    nil,
			"price":                23.2,
			"tax_amount":           4.64,
			"tax_percentage":       20,
			"inventory_offset":     0,
			"type":                 15,
			"role":                 0,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         false,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes":           bson.M{},
		},
		{
			"created": time.Now(),
			"updated": time.Now(),
			"code":    "landlord_eic_report",
			"title":   "Electrical Installation Condition Report",
			"description": "An Electrical Installation Condition Report (EICR) is required; as all " +
				"electrical installations will deteriorate over time. The report is valid for up to five years " +
				"but we recommend more regular checks.",
			"reference_provider":   "",
			"page_url":             "https://mashroom.com/services/eicr",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2021/07/eicr.png",
			"inventory_account":    "",
			"inventory_code":       "10",
			"service_receivers":    nil,
			"price":                187.5,
			"tax_amount":           37.5,
			"tax_percentage":       20,
			"inventory_offset":     0,
			"type":                 17,
			"role":                 4,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         true,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes": bson.M{
				"vibrant":                  "Electrical Installation Condition Report (EICR)",
				"document_type":            "certificate",
				"document_validity_months": "120",
			},
		},
		{
			"created": time.Now(),
			"updated": time.Now(),
			"code":    "landlord_inventory",
			"title":   "Inventory report",
			"description": "The inventory is a detailed description of each room in the property as " +
				"well as the content and fixtures and fittings. It’s a way of documenting everything in the " +
				"property and its general condition, with tenants asked to agree and sign the inventory. " +
				"Find out more here.",
			"reference_provider":   "",
			"page_url":             "",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2021/02/cib1.png",
			"inventory_account":    "207",
			"inventory_code":       "12",
			"service_receivers":    nil,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       20,
			"inventory_offset":     0,
			"type":                 4,
			"role":                 0,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         true,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": true,
			"price_on_request":     false,
			"attributes": bson.M{
				"document_type": "inventory",
			},
		},
		{
			"created": time.Now(),
			"updated": time.Now(),
			"code":    "landlord_inventory_check_in",
			"title":   "Inventory, check-in",
			"description": "This bundle of Inventory and Check-in simplifies your involvement in " +
				"the moving in process.",
			"reference_provider":   "",
			"page_url":             "https://mashroom.com/services/inventory",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2021/02/cib1.png",
			"inventory_account":    "207",
			"inventory_code":       "4",
			"service_receivers":    nil,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       20,
			"inventory_offset":     0,
			"type":                 11,
			"role":                 4,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         true,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": true,
			"price_on_request":     false,
			"attributes": bson.M{
				"vibrant":       "bson.M{bson.M{.FurnishedState}} Inventory and check-in bson.M{bson.M{.BedroomsNo}}bed",
				"document_type": "check_in_report",
			},
		},
		{
			"created":           parseDate("2021-05-18T15:27:01.521Z"),
			"updated":           time.Now(),
			"service_receivers": nil,
			"code":              "tenancy_claim_settlement",
			"title":             "Property damage settlement",
			"description": "Property damage settlement by landlord claim after tenancy has ended. " +
				"Tenant(s) agreed to pay for damage(s).",
			"reference_provider":   "",
			"type":                 18,
			"role":                 5,
			"status":               extras.ServiceStatus_ACTIVE,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       0,
			"tax_type":             1,
			"primary":              false,
			"cart_product":         false,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": true,
			"price_on_request":     false,
			"attributes":           bson.M{},
		},
		{
			"created": time.Now(),
			"updated": time.Now(),
			"code":    "content_insurance",
			"title":   "Contents Insurance",
			"description": "Contents insurance is a service offered to tenants to help them insure " +
				"their possessions at the rented property.",
			"reference_provider":   "",
			"page_url":             "https://mashroom.com/services/content-insurance",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2021/01/IR-3-icon.png",
			"inventory_account":    "205.3",
			"inventory_code":       "11",
			"service_receivers":    nil,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       12,
			"inventory_offset":     0,
			"type":                 19,
			"role":                 6,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             3,
			"primary":              false,
			"cart_product":         false,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": true,
			"price_on_request":     false,
			"attributes": bson.M{
				"document_type":            "contents_insurance",
				"document_validity_months": "12",
			},
		},
		{
			"created": parseDate("2021-08-20T10:39:36.567Z"),
			"updated": time.Now(),
			"code":    "gas-safety-boiler-service",
			"title":   "Gas Safety Certificate and Boiler Service",
			"description": "Cover all bases with a Gas Safety Certificate and Boiler Service. Both " +
				"services are carried out by Gas Safe registered engineers.",
			"reference_provider": "",
			"page_url":           "",
			"main_icon_url": "https://wordpress.mashroom.com/wp-content/uploads/2021/01/" +
				"Gas-safety-first-viewport-e1640083452771.png",
			"inventory_account":    "",
			"inventory_code":       "3",
			"service_receivers":    nil,
			"price":                82.5,
			"tax_amount":           16.5,
			"tax_percentage":       20,
			"inventory_offset":     0,
			"type":                 7,
			"role":                 0,
			"status":               0,
			"tax_type":             2,
			"primary":              false,
			"cart_product":         true,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes":           bson.M{},
		},
		{
			"created":              time.Now(),
			"updated":              time.Now(),
			"code":                 "landlord_rent_guarantee_insurance",
			"title":                "Rent Guarantee Insurance",
			"description":          "Protect your rental income by insuring any unpaid rent and your legal expenses.",
			"reference_provider":   "",
			"page_url":             "https://mashroom.com/services/rent-guarantee-insurance",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2021/07/mortgages.png",
			"inventory_account":    "205.2",
			"inventory_code":       "5",
			"service_receivers":    nil,
			"price":                266.96,
			"tax_amount":           32.04,
			"tax_percentage":       12,
			"inventory_offset":     0,
			"type":                 5,
			"role":                 7,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             3,
			"primary":              false,
			"cart_product":         true,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes": bson.M{
				"document_type":            "rent_guarantee_insurance",
				"document_validity_months": "12",
			},
		},
		{
			"created":              parseDate("2021-12-25T08:33:17.516Z"),
			"updated":              time.Now(),
			"code":                 "deposit-replacement-landlord",
			"title":                "Increased rental security",
			"description":          "",
			"reference_provider":   "",
			"page_url":             "https://mashroom.com/services/deposit-replacement-landlord",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2021/07/eicr.png",
			"inventory_account":    "",
			"inventory_code":       "",
			"service_receivers":    nil,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       0,
			"inventory_offset":     0,
			"type":                 0,
			"role":                 4,
			"status":               0,
			"tax_type":             1,
			"primary":              false,
			"cart_product":         false,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes":           bson.M{},
		},
		{
			"created":              parseDate("2021-12-25T08:33:50.788Z"),
			"updated":              time.Now(),
			"code":                 "tenant-referencing",
			"title":                "Tenant referencing",
			"description":          "",
			"reference_provider":   "",
			"page_url":             "https://mashroom.com/services/tenant-referencing",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2020/10/5.png",
			"inventory_account":    "",
			"inventory_code":       "",
			"service_receivers":    nil,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       20,
			"inventory_offset":     0,
			"type":                 0,
			"role":                 4,
			"status":               0,
			"tax_type":             1,
			"primary":              false,
			"cart_product":         false,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes": bson.M{
				"document_type": "referencing_report",
			},
		},
		{
			"created":              parseDate("2021-12-25T08:36:53.553Z"),
			"updated":              time.Now(),
			"code":                 "buy-to-let",
			"title":                "Buy to let",
			"description":          "",
			"reference_provider":   "",
			"page_url":             "https://mashroom.com/buy-to-let",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2020/09/landlord.png",
			"inventory_account":    "",
			"inventory_code":       "",
			"service_receivers":    nil,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       0,
			"inventory_offset":     0,
			"type":                 0,
			"role":                 8,
			"status":               0,
			"tax_type":             1,
			"primary":              false,
			"cart_product":         false,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes":           bson.M{},
		},
		{
			"created":              parseDate("2021-12-25T08:38:29.753Z"),
			"updated":              time.Now(),
			"code":                 "first-time-buyer",
			"title":                "First time buyer",
			"description":          "",
			"reference_provider":   "",
			"page_url":             "https://mashroom.com/first-time-buyer",
			"main_icon_url":        "https://wordpress.mashroom.com/wp-content/uploads/2021/06/Pricing-icons-5.png",
			"inventory_account":    "",
			"inventory_code":       "",
			"service_receivers":    nil,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       0,
			"inventory_offset":     0,
			"type":                 0,
			"role":                 8,
			"status":               0,
			"tax_type":             1,
			"primary":              false,
			"cart_product":         false,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes":           bson.M{},
		},
		{
			"created":            parseDate("2021-12-25T08:39:24.024Z"),
			"updated":            time.Now(),
			"code":               "remortgage",
			"title":              "Remortgage",
			"description":        "",
			"reference_provider": "",
			"page_url":           "https://mashroom.com/remortgage",
			"main_icon_url": "https://wordpress.mashroom.com/wp-content/uploads/2021/12/" +
				"remortgage@2x-75329cd59f89662430ee2589bad18220.png",
			"inventory_account":    "",
			"inventory_code":       "",
			"service_receivers":    nil,
			"price":                0,
			"tax_amount":           0,
			"tax_percentage":       0,
			"inventory_offset":     0,
			"type":                 0,
			"role":                 8,
			"status":               0,
			"tax_type":             1,
			"primary":              false,
			"cart_product":         false,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": false,
			"price_on_request":     false,
			"attributes":           bson.M{},
		},
		{
			"created":              parseDate("2022-04-14T15:35:06.410Z"),
			"updated":              time.Now(),
			"code":                 "tenant_first_month_deposit_replacement",
			"title":                "First month Deposit Replacement",
			"description":          "First month Deposit Replacement",
			"reference_provider":   "",
			"page_url":             "",
			"main_icon_url":        "",
			"inventory_account":    "205",
			"inventory_code":       "14",
			"service_receivers":    nil,
			"price":                0,
			"tax_amount":           20,
			"tax_percentage":       0,
			"inventory_offset":     0,
			"type":                 extras.ServiceType_DEPOSIT_INSURANCE,
			"role":                 extras.ServiceRole_TENANT_SERVICES,
			"status":               extras.ServiceStatus_ACTIVE,
			"tax_type":             extras.TaxType_TAX_TYPE_VAT,
			"primary":              false,
			"cart_product":         false,
			"disabled":             false,
			"obligatory":           false,
			"price_calculated":     false,
			"price_need_calculate": true,
			"price_on_request":     false,
			"attributes":           bson.M{},
		},
	}

	for _, p := range productionData {
		_, err := col.ReplaceOne(ctx, bson.M{"code": p["code"]}, p, options.Replace().SetUpsert(true))
		if err != nil {
			return -1, err
		}
	}

	codes := map[string]string{
		"gas-safety-boiler-service": extras.ProductLandlordGasSafetyBoilerService.String(),
		"content_insurance":         extras.ProductTenantContentInsurance.String(),
		"tenancy_claim_settlement":  extras.ProductTenantTenancyClaimSettlement.String(),
		"landlord_check_out":        extras.ProductLandlordInventoryCheckOut.String(),
	}

	for k, v := range codes {
		_, err := col.UpdateOne(
			ctx,
			bson.M{"code": k},
			bson.M{"$set": bson.M{"code": v}},
		)
		if err != nil {
			return -1, err
		}
	}

	_, err := col.InsertOne(
		ctx,
		&model.Service{
			Attributes:         map[extras.AttributeCode]string{},
			Created:            time.Now(),
			Updated:            time.Now(),
			Code:               extras.ProductTenantFirstMonthRent.String(),
			Title:              "First month rent minus holding deposit",
			Description:        "First month rent minus holding deposit",
			Type:               extras.ServiceType_RENT,
			Role:               extras.ServiceRole_TENANT_SERVICES,
			Status:             extras.ServiceStatus_ACTIVE,
			TaxType:            extras.TaxType_TAX_TYPE_NONE,
			PriceNeedCalculate: true,
		},
	)
	if err != nil {
		return -1, err
	}

	_, err = col.InsertOne(
		ctx,
		&model.Service{
			Attributes:         map[extras.AttributeCode]string{},
			Created:            time.Now(),
			Updated:            time.Now(),
			Code:               extras.ProductManagerViewingPayout.String(),
			Title:              "Viewing payout",
			Description:        "Viewing payout",
			Type:               extras.ServiceType_PAYOUT,
			Role:               extras.ServiceRole_MANAGER_SERVICES,
			Status:             extras.ServiceStatus_ACTIVE,
			TaxType:            extras.TaxType_TAX_TYPE_NONE,
			PriceNeedCalculate: true,
		},
	)
	if err != nil {
		return -1, err
	}

	_, err = col.InsertOne(
		ctx,
		&model.Service{
			Attributes:         map[extras.AttributeCode]string{},
			Created:            time.Now(),
			Updated:            time.Now(),
			Code:               extras.ProductLandlordRentPayout.String(),
			Title:              "Rent payout",
			Description:        "Rent payout",
			Type:               extras.ServiceType_RENT,
			Role:               extras.ServiceRole_LANDLORD_SERVICES,
			Status:             extras.ServiceStatus_ACTIVE,
			TaxType:            extras.TaxType_TAX_TYPE_NONE,
			PriceNeedCalculate: true,
		},
	)
	if err != nil {
		return -1, err
	}

	_, err = col.InsertOne(
		ctx,
		&model.Service{
			Attributes:         map[extras.AttributeCode]string{},
			Created:            time.Now(),
			Updated:            time.Now(),
			Code:               extras.ProductLandlordRentPayoutFee.String(),
			Title:              "Rent payout fee",
			Description:        "Rent payout fee",
			Type:               extras.ServiceType_RENT,
			Role:               extras.ServiceRole_LANDLORD_SERVICES,
			Status:             extras.ServiceStatus_ACTIVE,
			TaxType:            extras.TaxType_TAX_TYPE_NONE,
			PriceNeedCalculate: true,
		},
	)
	if err != nil {
		return -1, err
	}

	_, err = col.InsertOne(
		ctx,
		&model.Service{
			Attributes:         map[extras.AttributeCode]string{},
			Created:            time.Now(),
			Updated:            time.Now(),
			Code:               extras.ProductLandlordAdvancePayout.String(),
			Title:              "Advance payout",
			Description:        "Advance payout",
			Type:               extras.ServiceType_PAYOUT,
			Role:               extras.ServiceRole_LANDLORD_SERVICES,
			Status:             extras.ServiceStatus_ACTIVE,
			TaxType:            extras.TaxType_TAX_TYPE_NONE,
			PriceNeedCalculate: true,
		},
	)
	if err != nil {
		return -1, err
	}

	_, err = col.InsertOne(
		ctx,
		&model.Service{
			Attributes:         map[extras.AttributeCode]string{},
			Created:            time.Now(),
			Updated:            time.Now(),
			Code:               extras.ProductLandlordAdvancePayoutFee.String(),
			Title:              "Advance platform fee",
			Description:        "Advance platform fee",
			Type:               extras.ServiceType_PAYOUT,
			Role:               extras.ServiceRole_LANDLORD_SERVICES,
			Status:             extras.ServiceStatus_ACTIVE,
			TaxType:            extras.TaxType_TAX_TYPE_NONE,
			PriceNeedCalculate: true,
		},
	)
	if err != nil {
		return -1, err
	}

	_, err = col.InsertOne(
		ctx,
		&model.Service{
			Attributes:         map[extras.AttributeCode]string{},
			Created:            time.Now(),
			Updated:            time.Now(),
			Code:               extras.ProductTenantHoldingDeposit.String(),
			Title:              "Holding deposit",
			Description:        "Holding deposit",
			Type:               extras.ServiceType_DEPOSIT,
			Role:               extras.ServiceRole_TENANT_SERVICES,
			Status:             extras.ServiceStatus_ACTIVE,
			TaxType:            extras.TaxType_TAX_TYPE_NONE,
			PriceNeedCalculate: true,
		},
	)
	if err != nil {
		return -1, err
	}

	_, err = col.InsertOne(
		ctx,
		&model.Service{
			Attributes:         map[extras.AttributeCode]string{},
			Created:            time.Now(),
			Updated:            time.Now(),
			Code:               extras.ProductTenantStandingOrder.String(),
			Title:              "Standing order",
			Description:        "Standing order",
			Type:               extras.ServiceType_RENT,
			Role:               extras.ServiceRole_TENANT_SERVICES,
			Status:             extras.ServiceStatus_ACTIVE,
			TaxType:            extras.TaxType_TAX_TYPE_NONE,
			PriceNeedCalculate: true,
		},
	)
	if err != nil {
		return -1, err
	}

	return -1, nil
}
