package service

import (
	"math"

	extras "gitlab.mashplace.com/mashplace/backend/extras/api"
	"gitlab.mashplace.com/mashplace/backend/extras/internal/model"
	property "gitlab.mashplace.com/mashplace/backend/property/api"
)

func (srv *serviceImpl) renderService(m *model.Service, isAdminSite bool) *extras.Service {
	var remoteSalesPrices []float64

	var remoteSalesTaxes []float64

	if isAdminSite && len(m.RemoteSalesPrices) > 0 {
		remoteSalesPrices = make([]float64, 0)

		remoteSalesPrices = append(remoteSalesPrices, m.RemoteSalesPrices...)
	}

	if isAdminSite && len(m.RemoteSalesTaxes) > 0 {
		remoteSalesTaxes = make([]float64, 0)

		remoteSalesTaxes = append(remoteSalesTaxes, m.RemoteSalesTaxes...)
	}

	svc := &extras.Service{
		Id:                 &extras.Service_IdValue{IdValue: m.ID.Hex()},
		Code:               &extras.Service_CodeValue{CodeValue: m.Code},
		Type:               &extras.Service_TypeValue{TypeValue: m.Type},
		Status:             &extras.Service_StatusValue{StatusValue: m.Status},
		Role:               &extras.Service_RoleValue{RoleValue: m.Role},
		Price:              &extras.Service_PriceValue{PriceValue: m.Price},
		TaxType:            &extras.Service_TaxTypeValue{TaxTypeValue: m.TaxType},
		TaxAmount:          &extras.Service_TaxAmountValue{TaxAmountValue: m.TaxAmount},
		TaxPercentage:      &extras.Service_TaxPercentageValue{TaxPercentageValue: m.TaxPercentage},
		Title:              &extras.Service_TitleValue{TitleValue: m.Title},
		Primary:            &extras.Service_PrimaryValue{PrimaryValue: m.Primary},
		Description:        &extras.Service_DescriptionValue{DescriptionValue: m.Description},
		Obligatory:         &extras.Service_ObligatoryValue{ObligatoryValue: m.Obligatory},
		PriceNeedCalculate: &extras.Service_PriceNeedCalculateValue{PriceNeedCalculateValue: m.PriceNeedCalculate},
		PriceCalculated:    &extras.Service_PriceCalculatedValue{PriceCalculatedValue: m.PriceCalculated},
		PriceOnRequest:     &extras.Service_PriceOnRequestValue{PriceOnRequestValue: m.PriceOnRequest},
		ServiceReceivers: &extras.Service_ServiceReceiversValue{ServiceReceiversValue: &extras.ServiceReceivers{
			ServiceReceivers: srv.renderServiceReceivers(m.ServiceReceivers),
		}},
		Disabled:          &extras.Service_DisabledValue{DisabledValue: m.Disabled},
		ReferenceProvider: &extras.Service_ReferenceProviderValue{ReferenceProviderValue: m.ReferenceProvider},
		ReferenceId:       &extras.Service_ReferenceIdValue{ReferenceIdValue: m.ReferenceID},
		CartProduct:       &extras.Service_CartProductValue{CartProductValue: m.CartProduct},
		PageUrl:           &extras.Service_PageUrlValue{PageUrlValue: m.PageURL},
		MainIconUrl:       &extras.Service_MainIconUrlValue{MainIconUrlValue: m.MainIconURL},
		InventoryAccount:  &extras.Service_InventoryAccountValue{InventoryAccountValue: m.InventoryAccount},
		InventoryCode:     &extras.Service_InventoryCodeValue{InventoryCodeValue: m.InventoryCode},
		InventoryIndex: &extras.Service_InventoryIndexValue{
			InventoryIndexValue: m.InventoryOffset + int32(m.InventoryIndex),
		},
		InventoryOffset: &extras.Service_InventoryOffsetValue{InventoryOffsetValue: m.InventoryOffset},
		Attributes: &extras.Service_AttributesValue{
			AttributesValue: extras.NewAttributeList(m.Attributes),
		},
		RemoteSalesPrices: remoteSalesPrices,
		RemoteSalesTaxes:  remoteSalesTaxes,
	}

	svc.TaxAmount = &extras.Service_TaxAmountValue{TaxAmountValue: extras.TaxAmountService(svc)}

	return svc
}

func (srv *serviceImpl) renderServiceReceivers(ms []*model.ServiceReceiver) (svcs []*extras.ServiceReceiver) {
	for _, m := range ms {
		svcs = append(svcs, srv.renderServiceReceiver(m))
	}

	return
}

func (srv *serviceImpl) renderServiceReceiver(m *model.ServiceReceiver) *extras.ServiceReceiver {
	return &extras.ServiceReceiver{
		Code:    m.Code,
		Percent: m.Percent,
		Sum:     m.Sum,
	}
}

func (srv *serviceImpl) renderPropertyServices(
	prop *extras.Property,
	ms []*model.Service,
	calc, skip, isAdminSite bool,
) (results []*extras.Service) {
	for _, m := range ms {
		svc, err := srv.renderPropertyService(prop, m, calc, skip, isAdminSite)
		if svc == nil || err != nil {
			continue
		}

		results = append(results, svc)
	}

	return results
}

func (srv *serviceImpl) renderPropertyService(
	prop *extras.Property,
	m *model.Service,
	calc, skip, isAdminSite bool,
) (*extras.Service, error) {
	if calc && m.PriceNeedCalculate {
		err := srv.serviceCalculate(prop, m)
		if !skip && err != nil {
			return nil, err
		}

		if skip && !m.PriceCalculated {
			m.Price = 0
		}
	}

	return srv.renderService(m, isAdminSite), nil
}

func (srv *serviceImpl) serviceCalculate(prop *extras.Property, m *model.Service) error {
	switch m.Type {
	case extras.ServiceType_INVENTORY_REPORT, extras.ServiceType_BUNDLE:
		return srv.serviceCalculateInventoryReport(prop, m)
	case extras.ServiceType_DEPOSIT, extras.ServiceType_DEPOSIT_INSURANCE:
		return srv.serviceCalculateDeposit(prop, m)
	case extras.ServiceType_RENT_GUARANTEE_INSURANCE:
		return srv.serviceCalculateRentGuaranteeInsurance(prop, m)
	}

	return nil
}

func compareFurniture(codeValue, base string, furnValue, expect property.PropertyFurniture) bool {
	switch expect {
	case property.PropertyFurniture_PROPERTY_FURNITURE_UNFURNISHED:
		return codeValue == base+"_unfurnished" || (codeValue == base && furnValue == expect)
	case property.PropertyFurniture_PROPERTY_FURNITURE_FURNISHED:
		return codeValue == base+"_furnished" ||
			(codeValue == base &&
				(furnValue == expect || furnValue == property.PropertyFurniture_PROPERTY_FURNITURE_PARTLY_FURNISHED))
	}

	return false
}

func (srv *serviceImpl) serviceCalculateInventoryReport(
	prop *extras.Property,
	m *model.Service,
) error {
	if prop.GetDetails() == nil {
		return nil
	}

	furn := prop.GetDetails().GetAmenityFurniture()

	propDet := prop.GetDetails()

	if propDet.GetBedroomsNo() == nil {
		return nil
	}

	switch {
	case compareFurniture(
		m.Code,
		"landlord_inventory",
		furn,
		property.PropertyFurniture_PROPERTY_FURNITURE_UNFURNISHED,
	):
		m.InventoryIndex = clamp(int(propDet.GetBedroomsNo().GetValue()), 1, 5)
		m.Price = calculateBaseMaxPrice(108, m.InventoryIndex)
		m.Price, m.TaxAmount = adjustTax(m.Price, m.TaxPercentage)
		m.PriceCalculated = true
	case compareFurniture(
		m.Code,
		"landlord_inventory",
		furn,
		property.PropertyFurniture_PROPERTY_FURNITURE_FURNISHED,
	):
		m.InventoryIndex = clamp(int(propDet.GetBedroomsNo().GetValue()), 1, 5)
		m.Price = calculateBaseMaxPrice(122, m.InventoryIndex)
		m.Price, m.TaxAmount = adjustTax(m.Price, m.TaxPercentage)
		m.PriceCalculated = true
	case m.Code == "landlord_check_out":
		n := clamp(int(propDet.GetBedroomsNo().GetValue()), 1, 5)

		m.InventoryIndex = n

		switch n {
		case 1:
			m.Price = 144
		case 2:
			m.Price = 151
		case 3:
			m.Price = 158
		case 4:
			m.Price = 165
		case 5:
			m.Price = 172
		}

		m.Price, m.TaxAmount = adjustTax(m.Price, m.TaxPercentage)
		m.PriceCalculated = true
	case m.Code == "landlord_check_in":
		m.Price = 70
		m.Price, m.TaxAmount = adjustTax(m.Price, m.TaxPercentage)
		m.PriceCalculated = true
	case compareFurniture(
		m.Code,
		"landlord_inventory_check_in",
		furn,
		property.PropertyFurniture_PROPERTY_FURNITURE_FURNISHED,
	):
		m.InventoryIndex = clamp(int(propDet.GetBedroomsNo().GetValue()), 1, 5)

		m.Price = calculateBaseMaxPrice(144, m.InventoryIndex)

		m.Price, m.TaxAmount = adjustTax(m.Price, m.TaxPercentage)
		m.PriceCalculated = true
	case compareFurniture(
		m.Code,
		"landlord_inventory_check_in",
		furn,
		property.PropertyFurniture_PROPERTY_FURNITURE_UNFURNISHED,
	):
		m.InventoryIndex = clamp(int(propDet.GetBedroomsNo().GetValue()), 1, 5)
		m.Price = calculateBaseMaxPrice(115, m.InventoryIndex)
		m.Price, m.TaxAmount = adjustTax(m.Price, m.TaxPercentage)
		m.PriceCalculated = true
	case compareFurniture(
		m.Code,
		"landlord_inventory_check_out",
		furn,
		property.PropertyFurniture_PROPERTY_FURNITURE_FURNISHED,
	):
		n := clamp(int(propDet.GetBedroomsNo().GetValue()), 1, 5)

		m.InventoryIndex = n

		switch n {
		case 1:
			m.Price = 130
		case 2:
			m.Price = 155
		case 3:
			m.Price = 160
		case 4:
			m.Price = 170
		case 5:
			m.Price = 175
		}

		m.Price, m.TaxAmount = adjustTax(m.Price, m.TaxPercentage)
		m.PriceCalculated = true
	case compareFurniture(
		m.Code,
		"landlord_inventory_check_out",
		furn,
		property.PropertyFurniture_PROPERTY_FURNITURE_UNFURNISHED,
	):
		m.Price = calculateBaseMaxPrice(125, int(propDet.GetBedroomsNo().GetValue()))
		if m.Price == 130 {
			m.Price = 110
		}

		m.Price, m.TaxAmount = adjustTax(m.Price, m.TaxPercentage)
		m.PriceCalculated = true
	}

	return nil
}

func (srv *serviceImpl) serviceCalculateDeposit(prop *extras.Property, m *model.Service) error {
	if prop.GetRental() == nil && prop.GetConditions() == nil {
		return nil
	}

	price := prop.GetConditions().GetPrice()

	if price == 0 {
		price = prop.GetRental().GetRentalPrice().GetValue()
	}

	if price == 0 {
		return nil
	}

	switch m.Code {
	case "tenant_deposit":
		m.Price = extras.CalculateTraditionalDepositAmount(price)
		m.PriceCalculated = true
	case "tenant_deposit_replacement":
		m.Price = extras.CalculateDepositReplacementAmount(price)
		m.PriceCalculated = true
	}

	return nil
}

func (srv *serviceImpl) serviceCalculateRentGuaranteeInsurance(prop *extras.Property, m *model.Service) error {
	if prop.GetConditions() == nil {
		return nil
	}

	price := prop.GetConditions().GetPrice()

	switch {
	case price >= 1 && price <= 500:
		m.PriceCalculated = true
		m.Price, m.TaxAmount = 135.77, 16.29
	case price > 500 && price <= 700:
		m.PriceCalculated = true
		m.Price, m.TaxAmount = 147.09, 17.65
	case price > 700 && price <= 1000:
		m.PriceCalculated = true
		m.Price, m.TaxAmount = 154.29, 18.51
	case price > 1000 && price <= 1500:
		m.PriceCalculated = true
		m.Price, m.TaxAmount = 226.97, 27.24
	case price > 1500 && price <= 2000:
		m.PriceCalculated = true
		m.Price, m.TaxAmount = 317.83, 38.14
	case price > 2000:
		m.PriceCalculated = true
		m.Price, m.TaxAmount = 453.95, 54.47
	}

	return nil
}

func adjustTax(total, taxpercent float64) (price, tax float64) {
	tax = math.Round((total*taxpercent*100)/(100+taxpercent)) / 100
	price = total - tax

	return
}

func clamp(v, min, max int) int {
	if v < min {
		v = min
	}

	if v > max {
		v = max
	}

	return v
}

func calculateBaseMaxPrice(base float64, n int) (price float64) {
	return base + float64(clamp(n, 1, 5))*7
}
